diff src/defun-dld.h @ 2968:e330cb788508

[project @ 1997-05-15 17:40:29 by jwe]
author jwe
date Thu, 15 May 1997 17:54:17 +0000
parents 1a30f46e1870
children 35a6d027772c
line wrap: on
line diff
--- a/src/defun-dld.h
+++ b/src/defun-dld.h
@@ -33,11 +33,11 @@
 // time.
 //
 // If Octave is not configured for dynamic linking of builtin
-// functions, this is similar to DEFUN, except that it will generate
-// an extra static struct and an extra externally visible function.
+// functions, this is the same as DEFUN, except that it will generate
+// an extra externally visible function.
 //
 // The first DECLARE_FUN is for the struct, the second is for the
 // definition of the function.
 
 #if defined (MAKE_BUILTINS)
 #if ! (defined (OCTAVE_LITE) && defined (WITH_DYNAMIC_LINKING))
@@ -47,7 +47,7 @@
 #else
 #define DEFUN_DLD(name, args_name, nargout_name, doc) \
   DECLARE_FUN (name, args_name, nargout_name); \
-  DEFINE_FUN_STRUCT_FUN (name, doc) \
+  DEFINE_FUN_INSTALLER_FUN (name, doc) \
   DECLARE_FUN (name, args_name, nargout_name)
 #endif
@@ -33,11 +33,11 @@
 //
-// The first DECLARE_FUN is for the struct, the second is for the
-// definition of the function.
+// The first DECLARE_FUN is for the benefit of the installer function
+// and the second is for the definition of the function.
 
 #if defined (MAKE_BUILTINS)